/*
 * See Licensing and Copyright notice in naev.h
 */
#pragma once

#include "nlua.h"

int nlua_loadNaev( nlua_env *env );
